#!/usr/local/bin/python3.12
#
# This is an example of sending DNS queries over TLS (DoT) with dnspython.

import dns.message
import dns.query
import dns.rdatatype


def main():
    where = "1.1.1.1"
    qname = "example.com."
    q = dns.message.make_query(qname, dns.rdatatype.A)
    r = dns.query.tls(q, where)
    for answer in r.answer:
        print(answer)

        # ... do more lookups


if __name__ == "__main__":
    main()



#!/usr/local/bin/python3.12

import dns.message
import dns.query
import dns.tsig

key = dns.tsig.Key(
    "keyname.",
    "bnp6+y85UcBfsieuB/Uhx3EUsjc8wAFyyCSS5rhScb0=",
    algorithm=dns.tsig.HMAC_SHA256,
)


q = dns.message.make_query("example.", "SOA")
q.use_tsig(keyring=key)
r = dns.query.udp(q, "127.0.0.1")  # your authority address here
soa = r.find_rrset(r.answer, "example", "IN", "SOA")
print(soa)
